==> asserted-1.0.0.tgz: package/README.md <==
# asserted [![Build Status](http://img.shields.io/travis/alexmingoia/asserted.svg?style=flat)](http://travis-ci.org/alexmingoia/asserted) [![NPM version](http://img.shields.io/npm/v/asserted.svg?style=flat)](https://www.npmjs.org/package/asserted) [![Dependency Status](http://img.shields.io/david/alexmingoia/asserted.svg?style=flat)](https://david-dm.org/alexmingoia/asserted)

> A simple assertion interface for validation.

A simple extensible interface for validation assertions shipped with the
minimum assertions necessary for robust validations.

## Installation

Install using [npm](https://www.npmjs.org/):

```sh
npm install asserted
```
Install using [bower](http://bower.io/):

```sh
bower install asserted
```

Using browser script tag and global (UMD wrapper):

```html
// Available via window.asserted
<script src="dist/asserted.js"></script>
```

## API Reference
<a name="exp_module_asserted"></a>
##class: Assert ⏏
**Members**

* [class: Assert ⏏](#exp_module_asserted)
  * [new Assert(value, [message])](#exp_new_module_asserted)
  * [Assert.extend(message, fn)](#module_asserted.extend)
  * [Assert.TypeOf(type)](#module_asserted.TypeOf)
  * [Assert.InstanceOf(constructor)](#module_asserted.InstanceOf)
  * [Assert.Equals(value)](#module_asserted.Equals)
  * [Assert.Enum(set)](#module_asserted.Enum)
  * [Assert.Set(assert)](#module_asserted.Set)
  * [Assert.Range(range)](#module_asserted.Range)
  * [Assert.Length(length)](#module_asserted.Length)
  * [Assert.RegExp(regex)](#module_asserted.RegExp)

<a name="exp_new_module_asserted"></a>
###new Assert(value, [message])
Create a new assertion with given `value`.

Check `Assert#satisfied` and if false a failure message will be available
via `Assert#message`.

**Params**

- value `Mixed`  
- \[message\] `String` - override default message. %v is replaced with value  

**Returns**: `Assert`  
<a name="module_asserted.extend"></a>
###Assert.extend(message, fn)
Extend Assert with given `message` and assertion `fn`.

**Params**

- message `String` - %v is replaced with asserted value  
- fn `function` - assertion function returns boolean  

**Returns**: `Assert`  
<a name="module_asserted.TypeOf"></a>
###Assert.TypeOf(type)
Create assertion that value is type of given `type`.

**Params**

- type `String`  

**Returns**: `Assert`  
<a name="module_asserted.InstanceOf"></a>
###Assert.InstanceOf(constructor)
Create assertion that value is instance of given `constructor`.

**Params**

- constructor `function`  

**Returns**: `Assert`  
<a name="module_asserted.Equals"></a>
###Assert.Equals(value)
Create assertion that value is equal to given `value`.

**Params**

- value `Mixed`  

**Returns**: `Assert`  
<a name="module_asserted.Enum"></a>
###Assert.Enum(set)
Create assertion that value is in given `set`.

**Params**

- set `Array`  

**Returns**: `Assert`  
<a name="module_asserted.Set"></a>
###Assert.Set(assert)
Create assertion that value array members satisfy the given `assert`.

**Params**

- assert `Assert`  

**Returns**: `Assert`  
<a name="module_asserted.Range"></a>
###Assert.Range(range)
Create assertion that number value is within given `range`.

**Params**

- range `Object`  
  - min `Number`  
  - max `Number`  

**Returns**: `Assert`  
<a name="module_asserted.Length"></a>
###Assert.Length(length)
Create assertion that string or array value has given `length`.

**Params**

- length `Object` | `Number`  
  - \[min\] `Number`  
  - \[max\] `Number`  

**Returns**: `Assert`  
<a name="module_asserted.RegExp"></a>
###Assert.RegExp(regex)
Create assertion that value matches given `regex`.

**Params**

- regex `RegExp`  

**Returns**: `Assert`  


## Contributing

Please submit all issues and pull requests to the [alexmingoia/asserted](http://github.com/alexmingoia/asserted) repository!

## Tests

Run tests using `npm test` or `gulp test`.

## Code coverage

Generate code coverage using `gulp coverage` and open `coverage.html` in your
web browser.

## Support

If you have any problem or suggestion please open an issue [here](https://github.com/alexmingoia/asserted/issues).

==> asserted-1.1.0.tgz: package/README.md <==
# asserted [![Build Status](http://img.shields.io/travis/alexmingoia/asserted.svg?style=flat)](http://travis-ci.org/alexmingoia/asserted) [![NPM version](http://img.shields.io/npm/v/asserted.svg?style=flat)](https://www.npmjs.org/package/asserted) [![Dependency Status](http://img.shields.io/david/alexmingoia/asserted.svg?style=flat)](https://david-dm.org/alexmingoia/asserted)

> A simple assertion interface for validation.

A simple extensible interface for validation assertions shipped with the
minimum assertions necessary for robust validations.

## Installation

Install using [npm](https://www.npmjs.org/):

```sh
npm install asserted
```
Install using [bower](http://bower.io/):

```sh
bower install asserted
```

Using browser script tag and global (UMD wrapper):

```html
// Available via window.asserted
<script src="dist/asserted.js"></script>
```

## API Reference
<a name="exp_module_asserted"></a>
##class: Assert ⏏
**Members**

* [class: Assert ⏏](#exp_module_asserted)
  * [new Assert(value, [message])](#exp_new_module_asserted)
  * [Assert.extend(message, fn)](#module_asserted.extend)
  * [Assert.Type(type, [message])](#module_asserted.Type)
  * [Assert.Instance(constructor, [message])](#module_asserted.Instance)
  * [Assert.Equals(value, [message])](#module_asserted.Equals)
  * [Assert.Enum(set, [message])](#module_asserted.Enum)
  * [Assert.Set(assert, [message])](#module_asserted.Set)
  * [Assert.Range(range, [message])](#module_asserted.Range)
  * [Assert.Length(length, [message])](#module_asserted.Length)
  * [Assert.RegExp(regex, [message])](#module_asserted.RegExp)

<a name="exp_new_module_asserted"></a>
###new Assert(value, [message])
Create a new assertion with given `value`.

Check `Assert#satisfied` and if false a failure message will be available
via `Assert#message`.

**Params**

- value `Mixed`  
- \[message\] `String` - override default message. %v is replaced with value  

**Returns**: `Assert`  
<a name="module_asserted.extend"></a>
###Assert.extend(message, fn)
Extend Assert with given `message` and assertion `fn`.

**Params**

- message `String` - %v is replaced with asserted value  
- fn `function` - assertion function returns boolean  

**Returns**: `Assert`  
<a name="module_asserted.Type"></a>
###Assert.Type(type, [message])
Create assertion that value is type of given `type`.

**Params**

- type `String`  
- \[message\] `String`  

**Returns**: `Assert`  
<a name="module_asserted.Instance"></a>
###Assert.Instance(constructor, [message])
Create assertion that value is instance of given `constructor`.

**Params**

- constructor `function`  
- \[message\] `String`  

**Returns**: `Assert`  
<a name="module_asserted.Equals"></a>
###Assert.Equals(value, [message])
Create assertion that value is equal to given `value`.

**Params**

- value `Mixed`  
- \[message\] `String`  

**Returns**: `Assert`  
<a name="module_asserted.Enum"></a>
###Assert.Enum(set, [message])
Create assertion that value is in given `set`.

**Params**

- set `Array`  
- \[message\] `String`  

**Returns**: `Assert`  
<a name="module_asserted.Set"></a>
###Assert.Set(assert, [message])
Create assertion that value array members satisfy the given `assert`.

**Params**

- assert `Assert`  
- \[message\] `String`  

**Returns**: `Assert`  
<a name="module_asserted.Range"></a>
###Assert.Range(range, [message])
Create assertion that number value is within given `range`.

**Params**

- range `Object`  
  - min `Number`  
  - max `Number`  
- \[message\] `String`  

**Returns**: `Assert`  
<a name="module_asserted.Length"></a>
###Assert.Length(length, [message])
Create assertion that string or array value has given `length`.

**Params**

- length `Object` | `Number`  
  - \[min\] `Number`  
  - \[max\] `Number`  
- \[message\] `String`  

**Returns**: `Assert`  
<a name="module_asserted.RegExp"></a>
###Assert.RegExp(regex, [message])
Create assertion that value matches given `regex`.

**Params**

- regex `RegExp`  
- \[message\] `String`  

**Returns**: `Assert`  


## Contributing

Please submit all issues and pull requests to the [alexmingoia/asserted](http://github.com/alexmingoia/asserted) repository!

## Tests

Run tests using `npm test` or `gulp test`.

## Code coverage

Generate code coverage using `gulp coverage` and open `coverage.html` in your
web browser.

## Support

If you have any problem or suggestion please open an issue [here](https://github.com/alexmingoia/asserted/issues).
